Learn R Programming

admtools (version 0.4.0)

get_hiat_list: extract hiatus info

Description

returns a list with hiatus position and timing (start & end)

Usage

get_hiat_list(x)

Value

a list with one element per hiatus. each element is a named vector with the following entries:

  • "height" : stratigraphic position of hiatus

  • "start" : time when hiatus begins

  • "end" : time when hiatus ends

Arguments

x

an adm object

See Also

  • get_hiat_pos() to determine only stratigraphic position of hiatuses

  • get_hiat_no() to determine number of hiatuses in an adm

  • get_hiat_duration() to determine duration of hiatuses