returns a list with hiatus position and timing (start & end)
get_hiat_list(x)a list with one element per hiatus. each element is a named vector with the following entries:
"height" : stratigraphic position of hiatus
"start" : time when hiatus begins
"end" : time when hiatus ends
an adm object
get_hiat_pos() to determine only stratigraphic position of hiatuses
get_hiat_no() to determine number of hiatuses in an adm
get_hiat_duration() to determine duration of hiatuses